#
# spec file for package kpublictransport
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global sover   1
%global lname   libKPublicTransport%{sover}
%bcond_without released
Name:           kpublictransport
Version:        23.08.2
Release:        1.1
Summary:        QML imports for querying public transport data
License:        LGPL-2.0-or-later
URL:            https://www.kde.org
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  bison
BuildRequires:  extra-cmake-modules
BuildRequires:  fdupes
BuildRequires:  flex
%if 0%{?suse_version} == 1500
BuildRequires:  gcc10-c++
BuildRequires:  gcc10-PIE
%endif
BuildRequires:  kf5-filesystem
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5NetworkManagerQt)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(zlib)
Requires:       %{lname} = %{version}
Requires:       libKPublicTransportOnboard%{sover} = %{version}

%description
A library for access realtime public transport data and for performing public
ransport journey queries. QML imports.

%package -n %{lname}
Summary:        Library for querying public transport data

%description -n %{lname}
A library for access realtime public transport data and for performing public
ransport journey queries.

%package -n libKPublicTransportOnboard%{sover}
Summary:        Library for querying public transport data onboard trains
Requires:       %{lname} = %{version}

%description -n libKPublicTransportOnboard%{sover}
A library for access realtime public transport data and for performing public
transport journey queries. This package contains a library to determine 
the presence onboard of a train using WiFi SSIDs and provide journey 
details.

%package devel
Summary:        Library for querying public transport data
Requires:       %{lname} = %{version}
Requires:       libKPublicTransportOnboard%{sover} = %{version}
Requires:       extra-cmake-modules
Requires:       cmake(Qt5Gui)
Requires:       pkgconfig(zlib)

%description devel
A library for access realtime public transport data and for performing public
ransport journey queries.Development files.

%prep
%autosetup -p1

%build
%if 0%{?suse_version} == 1500
export CXX=g++-10
%endif
%cmake_kf5 -d build -- -DBUILD_TESTING=ON
%cmake_build

%install
%kf5_makeinstall -C build

%check
%ctest

%ldconfig_scriptlets -n %{lname}
%ldconfig_scriptlets -n libKPublicTransportOnboard%{sover}

%files
%dir %{_kf5_qmldir}/org/
%dir %{_kf5_qmldir}/org/kde/
%{_kf5_qmldir}/org/kde/kpublictransport/

%files -n %{lname}
%license LICENSES/*
%{_kf5_debugdir}/org_kde_kpublictransport.categories
%{_kf5_libdir}/libKPublicTransport.so.*

%files -n libKPublicTransportOnboard%{sover}
%{_kf5_libdir}/libKPublicTransportOnboard.so.*
%{_kf5_debugdir}/org_kde_kpublictransport_onboard.categories

%files devel
%{_includedir}/KPublicTransport/
%{_kf5_cmakedir}/KPublicTransport/
%{_kf5_libdir}/libKPublicTransport.so
%{_kf5_libdir}/libKPublicTransportOnboard.so

%changelog
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- Changes since 23.08.1:
  * test: querytest: Fixup au_navitia locations
  * networks: au_navitia: Use stop_point instead of stop_area
  * networks: au_navitia: Expand to all of Australia
  * networks: au_navitia: Fixup latitude and longitude
  * Fix typo in onboard API header installation
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- Changes since 23.07.90:
  * Remove coverage data without polygons from BVG and VBB
  * Don't limit vehicle layout queries to backends with realtime coverage
  * Remove the restriction for ÖBB vehicle layout requests on Austria
  * Support vehicle layouts for a few more ÖBB train types
  * Add support for ÖBB onboard API
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Too many changes to list here.
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- Changes since 23.04.2:
  * Drop implausible section paths
  * Apply check for physical limits also to walking sections
  * Fix long distance bus line mode for VOR
  * Remove dead OTP endpoints in Münster and Ulm
  * Also request the top-level transport mode for Entur stopover queries
  * Parse OTP transit legs without a transport mode subtype correctly
  * Make VRS work again
  * Add support for PKCS#12 client certificate bundles
  * Apply SSL configuration to IVV ASS network requests as well
  * Don't crash when setting custom QNAM when there isn't a default one yet
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- Changes since 23.04.1:
  * Exclude test input files that don't pass the JSON validation CI step
  * Drop substring notes during notes merging
  * Fix typo in parsing expected arrival times in DB Zugportal journeys
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- Changes since 23.04.0:
  * Propagate query job deletion to network jobs
  * Do name-based EFA location searches with type_sf=any
  * Add support for MAV onboard API
  * Add FlixTrain Wi-Fi SSID
  * Check for valid position numbers more strictly
  * Fix typo in CD Railjet WiFi SSID
  * Add UIC code of CD to backends that cover Czechia
  * Set proper polygons for all ÖBB coverage areas
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Changes since 21.12.3:
  * Add UIC coach sub-type mappings for CH and FR
  * Add overnight train coach types and parse corresponding UIC coach types
  * Include NightJet trains in supported types of the ÖBB vehicle layout API
  * Port to ECMQmlModule
  * Update coverage polygons from the Transport API Repository
  * Rewrite the train coach element rendering
  * Check name-based location search results for plausibility
  * Fix the backend identifier
  * tests: querytest: un_navitia: Add a Queensland test case
  * Allow to show headers in qtc6
  * Support EFA floor level difference attributes
  * Make isBackendEnabled() accessible from QML
  * Only list covered countries in the location picker
  * Make backend and coverage area objects accessbile from QML
  * Prefer nationwide providers for location searches with a known country
  * Add a configurable query delay for the location query model
  * Add a location history model
  * Remove superfluous export macro
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- No code change since 21.12.2
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- Changes since 21.12.1:
  * Disambiguate station name used in the Navitia name-based query tests
  * Fix Navitia location queries for rental bike stations and any type
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- Changes since 21.12.0:
  * Also register RentalVehicleStation for use from QML
  * Parse alternative Hafas platform format as well
  * Remove superfluous export macro
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- No code change since 21.11.90
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- Changes since 21.11.80:
  * Don't truncate path line segment lengths to integers
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Too many changes to list here.
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- Changes since 21.08.2:
  * Update SNCB certificate
  * Update OTP Ulm rental vehicle configuration
  * Pass along floating rented vehicle data correctly
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- Changes since 21.08.1:
  * Switch stadtnavi.de to OTP2
  * Correctly filter OTP results for discarded sharing networks
  * Only cache OTP location results if they contain no realtime elements
  * Consider all location request parameters for computing the cache key
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- Changes since 21.08.0:
  * Work around CMake Protobuf support not dealing with missing protoc
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- Changes since 21.07.80:
  * Propagate static timezones to intermediate stops as well
  * Add missing timezone for VRR
  * Propagate merged line data to intermediate stops
  * The isspace/isctrl/etc functions require unsigned char as input
  * Properly handle empty path sections in Hafas responses
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Too many changes to list here.
- Only install the license files once
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- No code change since 21.04.2
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- Changes since 21.04.1:
  * Fix parsing of numeric GBFS station ids
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- Changes since 21.04.0:
  * Fix cmake policy CMP0115 warning
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- No code change since 21.03.90
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- No code change since 21.03.80
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes to list here.
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- No code change since 20.12.2
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- No code change since 20.12.1
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- No code change since 20.12.0
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- No code change since 20.11.90
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- Changes since 20.11.80:
  * Set SOVERSION to a fixed value rather than the release service version
  * Disable Hafas binary journey queries on big endian systems
- Drop upstream patch:
  * 0001-Disable-Hafas-binary-journey-queries-on-big-endian-s.patch
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80.
  * New feature release
- kpublictransport is now released using the KDE release service.
- Add upstream patch:
  * 0001-Disable-Hafas-binary-journey-queries-on-big-endian-s.patch
* Mon Jul 22 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Initial commit
